@@ -19,6 +19,48 @@ import (
 	"k8s.io/client-go/informers"
 )
 
+func TestAsGVR(t *testing.T) {
+	a := dao.NewAlias(makeFactory())
+	a.Aliases.Define("v1/pods", "po", "pod", "pods")
+	a.Aliases.Define("workloads", "workloads", "workload", "wkl")
+
+	uu := map[string]struct {
+		cmd string
+		ok  bool
+		gvr client.GVR
+	}{
+		"ok": {
+			cmd: "pods",
+			ok:  true,
+			gvr: client.NewGVR("v1/pods"),
+		},
+		"ok-short": {
+			cmd: "po",
+			ok:  true,
+			gvr: client.NewGVR("v1/pods"),
+		},
+		"missing": {
+			cmd: "zorg",
+		},
+		"alias": {
+			cmd: "wkl",
+			ok:  true,
+			gvr: client.NewGVR("workloads"),
+		},
+	}
+
+	for k := range uu {
+		u := uu[k]
+		t.Run(k, func(t *testing.T) {
+			gvr, _, ok := a.AsGVR(u.cmd)
+			assert.Equal(t, u.ok, ok)
+			if u.ok {
+				assert.Equal(t, u.gvr, gvr)
+			}
+		})
+	}
+}
+
 func TestAliasList(t *testing.T) {
 	a := dao.Alias{}
 	a.Init(makeFactory(), client.NewGVR("aliases"))
@@ -49,24 +91,24 @@ func makeAliases() *dao.Alias {
 
 type testFactory struct{}
 
+func makeFactory() dao.Factory {
+	return testFactory{}
+}
+
 var _ dao.Factory = testFactory{}
 
 func (f testFactory) Client() client.Connection {
 	return nil
 }
-
 func (f testFactory) Get(gvr, path string, wait bool, sel labels.Selector) (runtime.Object, error) {
 	return nil, nil
 }
-
 func (f testFactory) List(gvr, ns string, wait bool, sel labels.Selector) ([]runtime.Object, error) {
 	return nil, nil
 }
-
 func (f testFactory) ForResource(ns, gvr string) (informers.GenericInformer, error) {
 	return nil, nil
 }
-
 func (f testFactory) CanForResource(ns, gvr string, verbs []string) (informers.GenericInformer, error) {
 	return nil, nil
 }
@@ -75,7 +117,3 @@ func (f testFactory) Forwarders() watch.Forwarders {
 	return nil
 }
 func (f testFactory) DeleteForwarder(string) {}
-
-func makeFactory() dao.Factory {
-	return testFactory{}
-}
